@@ -53,16 +53,22 @@ function(behavior,phaseX,v1){
   tf2=rf2/tf2sd
   x1=(c(seq(1:endA)))
   regA<-lm(A~x1)
-  l1=c("tf2=",as.character( round(tf2,3)))
+  DV<-( paste(substitute(behavior)) )
   writeLines(" ")
-  writeLines("------------------------------------Autocorrelation----------------------------")
-  cat(sprintf(l1),"\n") 
+  l5<-c("---------------------------Autocorrelation for behavior",'"',DV,'"',"in the", v1, "phase---------")
+  cat(sprintf(l5),"\n") 
+  l1=c("tf2=",as.character( round(tf2,3)))
+  #writeLines(" ")
+ # writeLines("------------------------------------Autocorrelation----------------------------")
+  
   
   l2=c("rf2=",as.character(round(rf2,3)))
- 
+  
+  cat(sprintf(l1),"\n")
   cat(sprintf(l2),"\n") 
   
   dfx=endA+5
+ 
 sig1<-pt(abs(tf2),df=dfx,lower.tail=FALSE)*2
   l3=c("sig of rf2=",as.character(round(sig1,3)))
   cat(sprintf(l3),"\n") 
@@ -95,7 +101,7 @@ sig1<-pt(abs(tf2),df=dfx,lower.tail=FALSE)*2
   yA<-regA$coefficients[1]
   BetaA<-regA$coefficient[2]
   #graphics.off()
-  layout(rbind(1,2), heights=c(4,1))
+  layout(rbind(1,2), heights=c(6,1))
   plot(x1,A,lwd=2,type="p",col="red", xlab="time", ylab="behavior", main=v1 )
   abline(c(yA,BetaA),col='Blue',lty="dashed")
   writeLines("-----------------------------------------")
