@@ -1,6 +1,12 @@
 Arobust <-
 function(behavior,phaseX,v1){
+  DV<-( paste(substitute(behavior)) )
   
+  l1<-c("Robust regression for behavior",'"',DV,'"',"in the", v1, "phase")
+  writeLines(" ")
+  cat(sprintf(l1),"\n")
+ 
+  writeLines("---------------------------------------------- ")
   t1<-table(phaseX)
   tmaxA<-t1[names(t1)==v1]
   startA<-match(v1,phaseX)
@@ -17,7 +23,7 @@ function(behavior,phaseX,v1){
   
   
   #graphics.off()
-  layout(rbind(1,2), heights=c(4,1))
+  layout(rbind(1,2), heights=c(6,1))
   plot(x1, A,lwd=2,type="o",col="red", xlab="time", ylab="behavior", main=v1 )
   abline(c(yA,BetaA),col='Blue',lty="dashed")
   print(summary(regA))
