@@ -49,6 +49,12 @@ function(behavior,phaseX,v1,v2){
   PEM<-c("PEM Below = ",as.character(round(p,2)))
   #print(PND)
   writeLines(" ")
+  DV<-( paste(substitute(behavior)) )
+  
+  l1<-c("PEM below for behavior",'"',DV,'"')
+  writeLines(" ")
+  cat(sprintf(l1),"\n")
+  writeLines(" ")
   cat(sprintf(PEM),"\n") 
   writeLines("-------------------------------------------")
   writeLines(".90 or above = very effective" )
@@ -56,7 +62,7 @@ function(behavior,phaseX,v1,v2){
   writeLines(".50 to .69 = debatable effectiveness")
   writeLines(" below .50 = not effective")
   #graphics.off()
-  layout(rbind(1,2), heights=c(4,1))
+  layout(rbind(1,2), heights=c(6,1))
   
   plot(iv,cdcl, ylim=c(0,max),lwd=2,type="o",col="red",bty="l", xlab="time", ylab="behavior", main="PEM" )
   
