@@ -4,12 +4,17 @@ meanNAP <-
     
 esmean<-mean(es,na.rm=T)
 essd<-sd(es,na.rm=T)
-writeLines("-----------mean-------------") 
-print(esmean)
-writeLines("------------SD--------------")
-print(essd)
-
-
+esmean<-as.character(round(esmean,3))
+essd<-as.character(round(essd,3))
+writeLines("")
+writeLines("mean")
+#print(esmean)
+cat(sprintf(esmean),"\n")
+writeLines("------------")
+writeLines("SD")
+#print(essd)
+cat(sprintf(essd),"\n")
+writeLines("")
 writeLines("-------------------------------------------")
 writeLines(".93 or above = very effective" )
 writeLines(".66 to .92 = moderate effectiveness")
@@ -20,6 +25,7 @@ writeLines(" ")
 
 e<-data.frame(es,lab)
 e<-e[ order(e$es), ]
+layout(rbind(1,2), heights=c(6,1))
 
 #dotchart(es,groups=lab,color="red",cex=.8, xlab="Cohen's D",main=esmain)
 dotchart(e$es,labels=e$lab,color="red",cex=.8, xlab="NAP",main=esmain)
