@@ -1,6 +1,14 @@
 medabove <-
 function (behavior,phaseX,v1,v2) {
-  medianab<-tapply(behavior,phaseX,median)
+  options (scipen=999)
+  options(warn=-1)
+  writeLines(" ")
+  DV<-( paste(substitute(behavior)) )
+  
+  l1<-c("Chi-square median above for behavior",'"',DV,'"',":")
+  cat(sprintf(l1),"\n")
+  writeLines(" ")
+   medianab<-tapply(behavior,phaseX,median)
    medianx=medianab[names(medianab)==v1]
   dzone<-behavior > medianx
   tm<-table(dzone,phaseX) 
@@ -40,4 +48,4 @@ function (behavior,phaseX,v1,v2) {
   par(mar=c(1, 1, 1, 1))
   plot.new()
   legend("center", c("behavior","median"), col = c("red","green"), lwd = 1,ncol=2,bty ="n")
-}
+  options(warn=-0)}
